<?php
namespace ElementorMailwizz;

class Mailwizz_Action_After_Submit extends \ElementorPro\Modules\Forms\Classes\Action_Base {
	/**
	 * Get Name
	 *
	 * Return the action name
	 *
	 * @access public
	 * @return string
	 */
	public function get_name() {
		return 'mailwizz';
	}

	/**
	 * Get Label
	 *
	 * Returns the action label
	 *
	 * @access public
	 * @return string
	 */
	public function get_label() {
		return __( 'OHWO', 'elementor-mailwizz' );
	}

	/**
	 * Run
	 *
	 * Runs the action after submit
	 *
	 * @access public
	 * @param \ElementorPro\Modules\Forms\Classes\Form_Record $record
	 * @param \ElementorPro\Modules\Forms\Classes\Ajax_Handler $ajax_handler
	 */
	public function run( $record, $ajax_handler ) {
		$settings = $record->get( 'form_settings' );

		//  Make sure that there is a Sendy list ID
		if ( empty( $settings['mailwizz_list'] ) ) {
			return;
		}


		// Get sumitetd Form data
		$raw_fields = $record->get( 'fields' );

		// Normalize the Form Data
		$fields = [];
		foreach ( $raw_fields as $id => $field ) {
			$fields[ $id ] = $field['value'];
		}

		// Make sure that the user emtered an email
		// which is required by Sendy's API to subsribe a user
		if ( empty( $settings['mailwizz_list'] ) ) {
			return;
		}


		$apiUrl = get_option('api_url');
        $publicKey = get_option('api_public_key');
        $privateKey = get_option('api_private_key');

        if(!$apiUrl && !$publicKey && !$privateKey){
            return;
        }

        
        if(!isset($fields['fname']) && isset($fields['name'])){
            $fields['fname'] = $fields['name'];
        }
        $fields['list'] = $settings['mailwizz_list'];
        // echo json_encode($fields);wp_die();
        $response = \Requests::post($apiUrl.'/subscribers/user/add',['public-key'=>$publicKey,'private-key'=>$privateKey],json_encode($fields));

        
        if($response->status_code == 200){
            $data = json_decode($response->body);
            if($data->status == 'success'){
               // echo json_encode(['success' => true, 'data' => ['message' => 'Submision succesfully']]);
               // wp_die();
            }else{
                $errors = $data->result;

                $messages = [];
                if(!is_array($errors)) $messages[] = $errors;
                else
	                foreach ($errors as $key => $value) {
	                    $messages[] = $key . ': ' . $value;
	                }
                echo json_encode(['success'=>false,'data'=>['message'=>$messages]]);
                wp_die();
            }
        }
        else{
            $data = json_decode($response->body);

            $errors = $data->result;
            $messages = [];
            if(!is_array($errors)) $messages[] = $errors;
            else
            foreach ($errors as $key => $value) {
                $messages[] = $key . ': ' . $value;
            }
            echo json_encode(['success'=>false,'data'=>['message'=>$messages]]);

            wp_die();
        }
	}

	/**
	 * Register Settings Section
	 *
	 * Registers the Action controls
	 *
	 * @access public
	 * @param \Elementor\Widget_Base $widget
	 */
	public function register_settings_section( $widget ) {


		$publicKey = esc_attr( get_option('api_public_key'));
		$privateKey = esc_attr( get_option('api_private_key'));
		$apiUrl = esc_attr( get_option('api_url'));
		
		$listsListOption = get_option('lists_list');
        $listsList =[];
        if($listsListOption){
            $listsList = json_decode($listsListOption);
        }
        $defaultList = get_option('list_default');
        $defaultList = null;
        $listOptions = [];
        if(count($listsList)){
        	foreach ($listsList as $list) {
        		$listOptions[$list->id] = $list->name;
        	}
        }

		if(!$apiUrl && !$publicKey && !$privateKey){
                
        }

		$widget->start_controls_section(
			'section_mailwizz',
			[
				'label' => __( 'OHWO', 'elementor-mailwizz' ),
				'condition' => [
					'submit_actions' => $this->get_name(),
				],
			]
		);

		// $widget->add_control(
		// 	'mailwizz_required_fields',
		// 	[
		// 		'label' => __( 'Required fields: [EMAIL] [FNAME]', 'elementor-mailwizz' ),
		// 		'type' => \Elementor\Controls_Manager::HEADING,
				
		// 	]
		// );



		$widget->add_control(
			'mailwizz_list',
			[
				'label' => __( 'OHWO List', 'elementor-mailwizz' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => $defaultList,
				'options' => $listOptions
			]
		);


		// $widget->add_control(
		// 	'mailwizz_request_lists',
		// 	[
		// 		// 'label' => __( 'Get latest data', 'elementor-mailwizz' ),
		// 		'type' => \Elementor\Controls_Manager::BUTTON,
		// 		'button_type' => 'success',
		// 		'text' => __( 'Get latest list data', 'elementor-mailwizz' ),
		// 		'separator' => 'before'
		// 		// 'event' => 'namespace:editor:delete',
				
		// 	]
		// );

		$widget->end_controls_section();

	}

	/**
	 * On Export
	 *
	 * Clears form settings on export
	 * @access public
	 * @param array $element
	 */
	public function on_export( $element ) {
		unset(
			$element['mailwizz_list']
		);
	}
}