<?php
/**
 * Plugin Name: Elementor Ohwo
 * Plugin URI:
 * Description: Plugin helping submission Elementor form data to Mailwizz
 * Version: 1.4
 * Author: ABSoft
 * Author URI: https://absoft.com.vn
 */
namespace ElementorMailwizz;

if ( ! defined( 'ABSPATH' ) ) exit;

define( 'ELEMENT_MAILWIZZ_PLUGIN', __FILE__ );
define( 'ELEMENT_MAILWIZZ_PLUGIN_DIR', untrailingslashit( dirname( ELEMENT_MAILWIZZ_PLUGIN ) ) );

class ElementorMailwizzPlugin{

    /**
     * Instance
     *
     * @access private
     * @static
     *
     * @var Plugin The single instance of the class.
     */
    private static $_instance = null;

    /**
     * Instance
     *
     * Ensures only one instance of the class is loaded or can be loaded.
     *
     * @since 1.2.0
     * @access public
     *
     * @return Plugin An instance of the class.
     */
    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function __construct() {

        // Register widget scripts
        // add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );

        // Register widgets
        // add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );

        // new ElementorMailwizzSetting();
        // Send API to Maiwizz
        /*
        add_action( 'elementor_pro/forms/new_record', function( $record, $handler ) {
            $apiUrl = get_option('api_url');
            $publicKey = get_option('api_public_key');
            $privateKey = get_option('api_private_key');
            $listDefault= get_option('list_default');
            if(!$apiUrl && !$publicKey && !$privateKey && !$listDefault){
                return;
            }
            //make sure its our form
            $form_name = $record->get_form_settings( 'form_name' );

            
            $raw_fields = $record->get( 'fields' );
            $fields = [];
            foreach ( $raw_fields as $id => $field ) {
                $fields[ $id ] = $field['value'];
            }
            if(!isset($fields['fname']) && isset($fields['name'])){
                $fields['fname'] = $fields['name'];
            }
            $fields['list'] = $listDefault;

            $response = Requests::post($apiUrl.'/subscribers/user/add',['public-key'=>$publicKey,'private-key'=>$privateKey],json_encode($fields));
            if($response->status_code == 200){
                $data = json_decode($response->body);
                if($data->status == 'success'){
                   // echo json_encode(['success' => true, 'data' => ['message' => 'Submision succesfully']]);
                   // wp_die();
                }else{
                    $errors = $data->error;
                    $messages = [];
                    foreach ($errors as $key => $value) {
                        $messages[] = $key . ': ' . $value;
                    }
                    echo json_encode(['success'=>false,'data'=>['message'=>$messages]]);
                    wp_die();
                }
            }
            else{
                $data = json_decode($response->body);

                $errors = $data->error;
                $messages = [];
                foreach ($errors as $key => $value) {
                    $messages[] = $key . ': ' . $value;
                }
                echo json_encode(['success'=>false,'data'=>['message'=>$messages]]);

                wp_die();
            }
        }, 10, 2 );

*/

        // add_action( 'elementor/dynamic_tags/register_tags', function( $dynamic_tags ) {
        //     // In our Dynamic Tag we use a group named request-variables so we need 
        //     // To register that group as well before the tag
        //     \Elementor\Plugin::$instance->dynamic_tags->register_group( 'request-variables', [
        //         'title' => 'Request Variables' 
        //     ] );

        //     // Include the Dynamic tag class file
        //     include_once( ELEMENT_MAILWIZZ_PLUGIN_DIR.'/elementor-server-var-tag.php' );

        //     // Finally register the tag
        //     $dynamic_tags->register_tag( 'Elementor_Server_Var_Tag' );
        // } );

        // $this->register_admin_function();

        require_once ELEMENT_MAILWIZZ_PLUGIN_DIR . '/settings.php';


        add_action( 'elementor_pro/init', function() {
            // Here its safe to include our action class file
            // include_once( 'path/to/action/class/file' );
            require_once ELEMENT_MAILWIZZ_PLUGIN_DIR . '/elementor-mailwizz-action.php';
            // Instantiate the action class
            $mailwizz_action = new Mailwizz_Action_After_Submit();

            // Register the action with form widget
            \ElementorPro\Plugin::instance()->modules_manager->get_modules( 'forms' )->add_form_action( $mailwizz_action->get_name(), $mailwizz_action );
        });
    }


    public function register_widgets() {
        // Its is now safe to include Widgets files
        //register widget
        require_once ELEMENT_MAILWIZZ_PLUGIN_DIR . '/elementor-mailwizz-widget.php';
        
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Elementor_Mailwizz_Widget() );
    }

    public function register_admin_function(){
        add_action('admin_menu', 'element_mailwizz_plugin_create_menu');
        
        add_action( 'wp_ajax_nopriv_get_list_mailwizz', 'action_get_list_to_mailwizz' );
        add_action( 'wp_ajax_get_list_mailwizz', 'action_get_list_to_mailwizz' );

        add_action( 'admin_enqueue_scripts', 'register_scripts' );
    }

    private function register_scripts(){
        wp_enqueue_script( 'element-mailwizz-admin',
            $this->element_mailwizz_plugin_url( 'assets/js/setting.js' ),
            array( 'jquery', 'jquery-ui-tabs' ),
            1.0, true
        );
        wp_enqueue_style ('elementor-mailwizz-style', $this->element_mailwizz_plugin_url('assets/css/style.css'), array(), '5.1.5');

    }

    public function element_mailwizz_plugin_create_menu() {

        //create new top-level menu
        add_menu_page('Elementor Ohwo', 'Elementor aaOhwo', 'administrator', __FILE__, 'element_mailwizz_plugin_settings_page'  );

        //call register settings function
        add_action( 'admin_init', 'register_element_mailwizz_plugin_settings' );
    }


    public function register_element_mailwizz_plugin_settings() {
        //register our settings
        register_setting( 'element-mailwizz-plugin-settings-group', 'api_public_key' );
        register_setting( 'element-mailwizz-plugin-settings-group', 'api_private_key' );
        register_setting( 'element-mailwizz-plugin-settings-group', 'api_url' );
        register_setting( 'element-mailwizz-plugin-settings-group', 'list_default' );
        register_setting( 'element-mailwizz-plugin-settings-group', 'lists_list' );
    }

    public function element_mailwizz_plugin_settings_page() {
        $listsListOption = get_option('lists_list');
        $listsList =[];
        if($listsListOption){
            $listsList = json_decode($listsListOption);
        }
        ?>
        <div class="wrap" id="elementor-mailwizz-setting">
            <h1>Elementor OHWO Setting</h1>
            <form method="post" action="options.php">
                <?php settings_fields( 'element-mailwizz-plugin-settings-group' ); ?>
                <?php do_settings_sections( 'element-mailwizz-plugin-settings-group' ); ?>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row">API URL</th>
                        <td><input type="text" readonly="readonly" name="api_url" value="https://app.ohwo.com/apiwrap/index.php" /></td>
                    </tr>

                    <tr valign="top">
                        <th scope="row">API Public Key</th>
                        <td><input type="text" name="api_public_key" value="<?php echo esc_attr( get_option('api_public_key') ); ?>" />  </td>
                    </tr>

                    <tr valign="top">
                        <th scope="row">API Private Key</th>
                        <td><input type="text" name="api_private_key" value="<?php echo esc_attr( get_option('api_private_key') ); ?>" />  </td>
                    </tr>

                    <tr valign="top">
                        <th scope="row">List</th>
                        <td>
                            <select name="list_default" >
                                <option value="">Choose List</option>
                                <?php if(count($listsList) >0): ?>
                                    <?php foreach ($listsList as $list): ?>
                                        <option <?=$list->id == get_option('list_default') ? 'selected' : '' ?> value="<?=$list->id?>"><?=$list->name?></option>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </select> - <a id="get_list" href="javascript:void(0);" class="btn">Get Lists</a>
                        </td>
                    </tr>
                    <input type="hidden" name="lists_list" value="<?php echo esc_attr( get_option('lists_list') ); ?>"/>
                </table>

                <?php submit_button(); ?>

            </form>
        </div>
    <?php } 
    private function action_get_list_to_mailwizz() {
        global $wpdb; // this is how you get access to the database
        $url = $_POST['url'];
        $public_key = $_POST['public_key'];
        $private_key = $_POST['private_key'];
        $response = Requests::get($url.'/lists/show',['public-key'=>$public_key,'private-key'=>$private_key]);
        if($response->status_code == 200){
            $data = json_decode($response->body);
            if($data->status == 'success'){
                $result = [];
                $records = $data->data->records;
                foreach ($records as $record){
                    $result[] = [
                        'id'=>$record->general->list_uid,
                        'name' => $record->general->name
                    ];
                }
                echo json_encode($result);
            }
            wp_die();
        }

        wp_die();
    }

    public function element_mailwizz_plugin_url( $path = '' ) {
        $url = plugins_url( $path, ELEMENT_MAILWIZZ_PLUGIN );

        if ( is_ssl()
            and 'http:' == substr( $url, 0, 5 ) ) {
            $url = 'https:' . substr( $url, 5 );
        }

        return $url;
    }

}

ElementorMailwizzPlugin::instance();